%define	upstream_name	 Readonly-XS
%define upstream_version 1.05

%{?perl_default_filter}

Name:		perl-%{upstream_name}
Version:	%perl_convert_version %{upstream_version}
Release:	%mkrel 26

Summary:	Companion module for Readonly.pm, to speed up read-only scalar variables
License:	GPL+ or Artistic
Group:		Development/Perl
Url:		https://metacpan.org/release/%{upstream_name}
Source0:	https://cpan.metacpan.org/modules/by-module/Readonly/%{upstream_name}-%{upstream_version}.tar.gz

Buildrequires:	perl-devel

%description
The Readonly module (q.v.) is an effective way to create non-modifiable
variables. However, it's relatively slow.

The reason it's slow is that is implements the read-only-ness of variables via
tied objects. This mechanism is inherently slow. Perl simply has to do a lot of
work under the hood to make tied variables work.

This module corrects the speed problem, at least with respect to scalar
variables. When Readonly::XS is installed, Readonly uses it to access the
internals of scalar variables. Instead of creating a scalar variable object and
tying it, Readonly simply flips the SvREADONLY bit in the scalar's FLAGS
structure.

Readonly arrays and hashes are not sped up by this, since the SvREADONLY flag
only works for scalars. Arrays and hashes always use the tie interface.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build CFLAGS="%{optflags}"

%check
%{__make} test

%install
%make_install

%files 
%doc Changes README
%{perl_vendorarch}/Readonly
%{perl_vendorarch}/auto/Readonly
%{_mandir}/*/*




%changelog
* Tue Jun 07 2022 umeabot <umeabot> 1.50.0-26.mga9
+ Revision: 1862363
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 1.50.0-25.mga9
+ Revision: 1796019
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 1.50.0-24.mga9
+ Revision: 1727052
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 1.50.0-23.mga8
+ Revision: 1595150
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 1.50.0-22.mga8
+ Revision: 1530092
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Aug 27 2019 tmb <tmb> 1.50.0-21.mga8
+ Revision: 1433886
- rebuild for perl 5.30

* Fri Sep 21 2018 umeabot <umeabot> 1.50.0-20.mga7
+ Revision: 1293742
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 1.50.0-19.mga7
+ Revision: 1249261
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 1.50.0-18.mga7
+ Revision: 1166397
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 1.50.0-17.mga7
+ Revision: 1149118
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 1.50.0-16.mga7
+ Revision: 1126442
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 1.50.0-15.mga6
+ Revision: 1032720
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 1.50.0-14.mga6
+ Revision: 957944
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 1.50.0-13.mga6
+ Revision: 845195
- rebuild for soname-ifed perl

* Wed Jun 24 2015 sander85 <sander85> 1.50.0-12.mga6
+ Revision: 841756
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 1.50.0-11.mga5
+ Revision: 739331
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.50.0-10.mga5
+ Revision: 686089
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 1.50.0-9.mga5
+ Revision: 631613
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 1.50.0-8.mga4
+ Revision: 524993
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 1.50.0-7.mga4
+ Revision: 431737
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.50.0-6.mga3
+ Revision: 372239
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 1.50.0-5.mga3
+ Revision: 251089
- rebuild for perl 5.16

* Sun Jun 12 2011 sander85 <sander85> 1.50.0-4.mga2
+ Revision: 104936
- Rebuild for perl 5.14

* Thu Jan 13 2011 jquelin <jquelin> 1.50.0-3.mga1
+ Revision: 14348
- imported package perl-Readonly-XS


* Tue Jul 20 2010 Jérôme Quelin <jquelin@mandriva.org> 1.50.0-3mdv2011.0
+ Revision: 556138
- rebuild for perl 5.12
- rebuild for perl 5.12

* Wed Jul 29 2009 Jérôme Quelin <jquelin@mandriva.org> 1.50.0-1mdv2010.0
+ Revision: 404353
- rebuild using %%perl_convert_version

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.05-1mdv2009.1
+ Revision: 344647
- new version

* Thu Jul 31 2008 Thierry Vignaud <tv@mandriva.org> 1.04-9mdv2009.0
+ Revision: 258281
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 1.04-8mdv2009.0
+ Revision: 246345
- rebuild

* Thu Feb 28 2008 Jérôme Quelin <jquelin@mandriva.org> 1.04-6mdv2008.1
+ Revision: 176251
- applying patch to build against perl 5.10

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Sep 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-3mdv2008.0
+ Revision: 86821
- rebuild


* Thu Aug 31 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-2mdv2007.0
- Rebuild

* Sun Apr 23 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-1mdk
- first mdk release

